==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkBiDimensionalWidget.java <==
// java wrapper for vtkBiDimensionalWidget object
//

package vtk;
import vtk.*;

public class vtkBiDimensionalWidget extends vtkAbstractWidget
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEnabled_2(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_2(id0); }

  private native void SetRepresentation_3(vtkBiDimensionalRepresentation id0);
  public void SetRepresentation(vtkBiDimensionalRepresentation id0)
    { SetRepresentation_3(id0); }

  private native long GetBiDimensionalRepresentation_4();
  public vtkBiDimensionalRepresentation GetBiDimensionalRepresentation() {
    long temp = GetBiDimensionalRepresentation_4();

    if (temp == 0) return null;
    return (vtkBiDimensionalRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CreateDefaultRepresentation_5();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_5(); }

  private native int IsMeasureValid_6();
  public int IsMeasureValid()
    { return IsMeasureValid_6(); }

  private native void SetProcessEvents_7(int id0);
  public void SetProcessEvents(int id0)
    { SetProcessEvents_7(id0); }

  private native void SetWidgetStateToStart_8();
  public void SetWidgetStateToStart()
    { SetWidgetStateToStart_8(); }

  private native void SetWidgetStateToManipulate_9();
  public void SetWidgetStateToManipulate()
    { SetWidgetStateToManipulate_9(); }

  private native int GetWidgetState_10();
  public int GetWidgetState()
    { return GetWidgetState_10(); }

  public vtkBiDimensionalWidget() { super(); }

  public vtkBiDimensionalWidget(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkBiDimensionalWidget.java <==
// java wrapper for vtkBiDimensionalWidget object
//

package vtk;
import vtk.*;

public class vtkBiDimensionalWidget extends vtkAbstractWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEnabled_2(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_2(id0); }

  private native void SetRepresentation_3(vtkBiDimensionalRepresentation id0);
  public void SetRepresentation(vtkBiDimensionalRepresentation id0)
    { SetRepresentation_3(id0); }

  private native long GetBiDimensionalRepresentation_4();
  public vtkBiDimensionalRepresentation GetBiDimensionalRepresentation() {
    long temp = GetBiDimensionalRepresentation_4();

    if (temp == 0) return null;
    return (vtkBiDimensionalRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultRepresentation_5();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_5(); }

  private native int IsMeasureValid_6();
  public int IsMeasureValid()
    { return IsMeasureValid_6(); }

  private native void SetProcessEvents_7(int id0);
  public void SetProcessEvents(int id0)
    { SetProcessEvents_7(id0); }

  private native void SetWidgetStateToStart_8();
  public void SetWidgetStateToStart()
    { SetWidgetStateToStart_8(); }

  private native void SetWidgetStateToManipulate_9();
  public void SetWidgetStateToManipulate()
    { SetWidgetStateToManipulate_9(); }

  private native int GetWidgetState_10();
  public int GetWidgetState()
    { return GetWidgetState_10(); }

  public vtkBiDimensionalWidget() { super(); }

  public vtkBiDimensionalWidget(long id) { super(id); }
  public native long   VTKInit();

}
